Using Hutchinson's method
randTraceHutchinson(L, numVectors)a scalar
A pedigree's L inverse matrix
an integer specifying how many random vectors to use
If you do not have a good reason to do otherwise, use the function hutchpp instead.
The higher numVectors, the higher the accuracy and the longer the running time.
Accuracy can be estimated with the function getNumVectorsHutchinson.